@@ -163,12 +163,8 @@ my $_unquote = sub {
 };
 
 # Private methods
-my $_db_attr = sub {
-   my $self = shift; my $attr = $self->connect_info->[ 3 ];
-
-   $attr->{ $_ } = $self->db_attr->{ $_ } for (keys %{ $self->db_attr });
-
-   return $attr;
+my $_connect_attr = sub {
+   return { %{ $_[ 0 ]->connect_info->[ 3 ] }, %{ $_[ 0 ]->db_attr } };
 };
 
 my $_get_db_admin_creds = sub {
@@ -194,7 +190,7 @@ my $_create_ddl = sub {
 
    my $version = $self->schema_version;
    my $schema  = $schema_class->connect
-      ( $self->dsn, $self->user, $self->password, $self->$_db_attr );
+      ( $self->dsn, $self->user, $self->password, $self->$_connect_attr );
 
    if ($self->unlink) {
       for my $rdb (@{ $self->rdbms }) {
@@ -205,7 +201,7 @@ my $_create_ddl = sub {
    }
 
    $schema->create_ddl_dir
-      ( $self->rdbms, $version, $dir, $self->preversion, $self->$_db_attr );
+      ( $self->rdbms, $version, $dir, $self->preversion, $self->$_connect_attr);
    return;
 };
 
@@ -220,9 +216,9 @@ my $_deploy_and_populate = sub {
    else {
       $self->info( "Deploying schema ${schema_class} and populating" );
       $schema = $schema_class->connect
-         ( $self->dsn, $self->user, $self->password, $self->$_db_attr );
+         ( $self->dsn, $self->user, $self->password, $self->$_connect_attr );
       $schema->storage->ensure_connected;
-      $schema->deploy( $self->$_db_attr, $dir );
+      $schema->deploy( $self->$_connect_attr, $dir );
    }
 
    my $dist  = distname $schema_class;
@@ -234,7 +230,7 @@ my $_deploy_and_populate = sub {
    for my $path ($io->all_files) {
       my ($class) = $path->filename =~ $re;
 
-      $res->{ $class } = $self->deploy_file( $schema, $split, $class, $path );
+      $res->{ $class } = $self->populate_class( $schema, $split, $class, $path);
    }
 
    return $res;
@@ -325,30 +321,8 @@ sub deploy_and_populate : method {
    return OK;
 }
 
-sub deploy_file {
-   my ($self, $schema, $split, $class, $path) = @_; my $res;
-
-   if ($class) { $self->output( "Populating ${class}" ) }
-   else        { $self->fatal ( 'No class in [_1]', $path->filename ) }
-
-   my $data = $self->file->dataclass_schema->load( $path );
-   my $flds = [ split SPC, $data->{fields} ];
-   my @rows = map { [ map { $_unquote->( trim $_ ) } $split->records( $_ ) ] }
-                 @{ $data->{rows} };
-
-   try {
-      if ($self->dry_run) { $self->dumper( $flds, \@rows ) }
-      else { $res = $schema->populate( $class, [ $flds, @rows ] ) }
-   }
-   catch {
-      if ($_->can( 'class' ) and $_->class eq 'ValidationErrors') {
-         $self->warning( "${_}" ) for (@{ $_->args });
-      }
-
-      throw $_;
-   };
-
-   return $res;
+sub deploy_file { # Deprecated
+   my $self = shift; return $self->populate_class( @_ );
 };
 
 sub drop_database : method {
@@ -410,6 +384,32 @@ sub edit_credentials : method {
    return OK;
 }
 
+sub populate_class {
+   my ($self, $schema, $split, $class, $path) = @_; my $res;
+
+   if ($class) { $self->output( "Populating ${class}" ) }
+   else        { $self->fatal ( 'No class in [_1]', $path->filename ) }
+
+   my $data = $self->file->dataclass_schema->load( $path );
+   my $flds = [ split SPC, $data->{fields} ];
+   my @rows = map { [ map { $_unquote->( trim $_ ) } $split->records( $_ ) ] }
+                 @{ $data->{rows} };
+
+   try {
+      if ($self->dry_run) { $self->dumper( $flds, \@rows ) }
+      else { $res = $schema->populate( $class, [ $flds, @rows ] ) }
+   }
+   catch {
+      if ($_->can( 'class' ) and $_->class eq 'ValidationErrors') {
+         $self->warning( "${_}" ) for (@{ $_->args });
+      }
+
+      throw $_;
+   };
+
+   return $res;
+}
+
 1;
 
 __END__
@@ -537,9 +537,7 @@ Called as part of the application install
 
 =head2 deploy_file
 
-   $result = $self->deploy_file( $schema, $split, $class, $path );
-
-Populates one table from a single file
+Deprecated in favour of L</populate_class>
 
 =head2 driver
 
@@ -579,6 +577,12 @@ L</dsn>
 
 The unencrypted password used to connect to the database
 
+=head2 populate_class
+
+   $result = $self->populate_class( $schema, $split, $class, $path );
+
+Populates one table from a single file
+
 =head2 user
 
    $self->user;
